==> ejc-bidprice-impl-3.0.0-20230209.024231-4-sources.jar: com/ejianc/business/bidprice/material/controller/MaterialPicketageController.java <==
package com.ejianc.business.bidprice.material.controller;

import java.io.Serializable;

import com.ejianc.business.bidprice.material.bean.MaterialPicketagePurchaseDetailEntity;
import com.ejianc.business.bidprice.material.bean.MaterialPicketageRentDetailEntity;
import com.ejianc.business.bidprice.material.bean.MaterialPicketageSupplierEntity;
import com.ejianc.business.bidprice.material.service.IMaterialPicketageSupplierService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.core.kit.collection.ListUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import com.ejianc.business.bidprice.material.bean.MaterialPicketageEntity;
import com.ejianc.business.bidprice.material.service.IMaterialPicketageService;
import com.ejianc.business.bidprice.material.vo.MaterialPicketageVO;

/**
 * 材料定标
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialPicketage")
@Api(value = "材料定标", tags = {"材料定标"})
public class MaterialPicketageController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "MATERIAL_PICKETAGE";//此处需要根据实际修改

    @Autowired
    private IMaterialPicketageService service;
    @Autowired
    private IMaterialPicketageSupplierService materialPicketageSupplierService;

    @Autowired
    private SessionManager sessionManager;

    @ApiOperation("新增或者修改")
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialPicketageVO> saveOrUpdate(@ApiParam(name="saveOrUpdateVO", required=true) @RequestBody MaterialPicketageVO saveOrUpdateVO) {
    	MaterialPicketageEntity entity = BeanMapper.map(saveOrUpdateVO, MaterialPicketageEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                //自制 签订数量
                entity.setSelfFlag(0);
                entity.setContractSign(0);
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        service.insertOrUpdate(entity);
    	MaterialPicketageVO vo = BeanMapper.map(entity, MaterialPicketageVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }


    @ApiOperation("查询详情")
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialPicketageVO> queryDetail(@RequestParam Long id) {
    	MaterialPicketageEntity entity = service.selectById(id);
        if(!ListUtil.isEmpty(entity.getMaterialPicketagePurchaseDetailList()) || !ListUtil.isEmpty(entity.getMaterialPicketageRentDetailList())){
            List<Long> detailIds = new ArrayList<>();
            List<Long> purchaseIds = entity.getMaterialPicketagePurchaseDetailList().stream().map(MaterialPicketagePurchaseDetailEntity::getId).collect(Collectors.toList());
            List<Long> rentIds = entity.getMaterialPicketageRentDetailList().stream().map(MaterialPicketageRentDetailEntity::getId).collect(Collectors.toList());
            detailIds.addAll(purchaseIds);
            detailIds.addAll(rentIds);
            Map<Long, List<MaterialPicketageSupplierEntity>> supplierMap=new HashMap<>();
            QueryParam param = new QueryParam();
            param.getParams().put("picketageDetailId",new Parameter(QueryParam.IN,rentIds));
            List<MaterialPicketageSupplierEntity> supplierEntities = materialPicketageSupplierService.queryList(param, false);
             if (CollectionUtils.isNotEmpty(supplierEntities)){
                  supplierMap = supplierEntities.stream().collect(Collectors.groupingBy(MaterialPicketageSupplierEntity::getPicketageDetailId));
             }
             if (!supplierMap.isEmpty()){
                 for (MaterialPicketageRentDetailEntity rent : entity.getMaterialPicketageRentDetailList()) {
                     rent.setMaterialPicketageSupplierList(supplierMap.get(rent.getId()));
                 }
                 for (MaterialPicketagePurchaseDetailEntity purchase : entity.getMaterialPicketagePurchaseDetailList()) {
                     purchase.setMaterialPicketageSupplierList(supplierMap.get(purchase.getId()));
                 }
             }
        }
    	MaterialPicketageVO vo = BeanMapper.map(entity, MaterialPicketageVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    @ApiOperation("批量删除单据")
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialPicketageVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MaterialPicketageVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MaterialPicketageVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }


    @ApiOperation("查询列表")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialPicketageVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("name");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("bidWinnerName");
        /** 租户隔离 */
        Map<String, Parameter> params = param.getParams();
        if (params.containsKey("contractSign")){
            Integer contractSign= Integer.parseInt(params.get("contractSign").getValue().toString());
            params.remove("contractSign");
            if (contractSign==1){
                param.getParams().put("contractSign", new Parameter(QueryParam.GT,0));
            }else {
                param.getParams().put("contractSign", new Parameter(QueryParam.EQ,0));
            }
        }
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        UserContext userContext = sessionManager.getUserContext();
        String authOrgIds = userContext.getAuthOrgIds();
        if (StringUtils.isNotEmpty(authOrgIds)) {
            CommonResponse<List<OrgVO>> authResponse =
                    iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).
                            collect(Collectors.toList()));
            param.getParams().put("orgId", new Parameter(QueryParam.IN, authResponse.getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        } else {
            param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        IPage<MaterialPicketageEntity> page = service.queryPage(param,false);
        IPage<MaterialPicketageVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialPicketageVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    @ApiOperation("导出")
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("name");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("bidWinnerName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        Map<String, Parameter> params = param.getParams();
        if (params.containsKey("contractSign")){
            Integer contractSign= Integer.parseInt(params.get("contractSign").getValue().toString());
            params.remove("contractSign");
            if (contractSign==1){
                param.getParams().put("contractSign", new Parameter(QueryParam.GT,0));
            }else {
                param.getParams().put("contractSign", new Parameter(QueryParam.EQ,0));
            }
        }
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialPicketageEntity>  list= service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<MaterialPicketageVO> vos = BeanMapper.mapList(list, MaterialPicketageVO.class);
        if (CollectionUtils.isNotEmpty(vos)){
            for (MaterialPicketageVO vo : vos) {
                vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
                vo.setPurchaseTypeName(vo.getPurchaseType()==1 ? "项目自采":"公司集采");
                vo.setPricingTypeName(vo.getPricingType()==1 ? "采购":"租赁");
                vo.setContractSignStr(vo.getContractSign()>0 ? vo.getContractSign()+"" : "未签订" );
            }
        }
        beans.put("records", vos);
        ExcelExport.getInstance().export("MaterialPicketage-export.xlsx", beans, response);
    }


    @ApiOperation("参照")
    @RequestMapping(value = "/refMaterialPicketageData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialPicketageVO>> refMaterialPicketageData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MaterialPicketageEntity> page = service.queryPage(param,false);
        IPage<MaterialPicketageVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialPicketageVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-bidprice-impl-3.0.0-20230209.114907-14-sources.jar: com/ejianc/business/bidprice/material/controller/MaterialPicketageController.java <==
package com.ejianc.business.bidprice.material.controller;

import java.io.Serializable;

import com.ejianc.business.bidprice.material.bean.MaterialPicketagePurchaseDetailEntity;
import com.ejianc.business.bidprice.material.bean.MaterialPicketageRentDetailEntity;
import com.ejianc.business.bidprice.material.bean.MaterialPicketageSupplierEntity;
import com.ejianc.business.bidprice.material.service.IMaterialPicketageSupplierService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import com.ejianc.business.bidprice.material.bean.MaterialPicketageEntity;
import com.ejianc.business.bidprice.material.service.IMaterialPicketageService;
import com.ejianc.business.bidprice.material.vo.MaterialPicketageVO;

/**
 * 材料定标
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialPicketage")
@Api(value = "材料定标", tags = {"材料定标"})
public class MaterialPicketageController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "MATERIAL_PICKETAGE";//此处需要根据实际修改

    @Autowired
    private IMaterialPicketageService service;
    @Autowired
    private IMaterialPicketageSupplierService materialPicketageSupplierService;

    @Autowired
    private SessionManager sessionManager;
//    @Autowired
//    private ICommonBusinessService materialPicketage;

    @ApiOperation("新增或者修改")
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialPicketageVO> saveOrUpdate(@ApiParam(name="saveOrUpdateVO", required=true) @RequestBody MaterialPicketageVO saveOrUpdateVO) {
    	MaterialPicketageEntity entity = BeanMapper.map(saveOrUpdateVO, MaterialPicketageEntity.class);
    	if (entity.getBidWinMny()!=null){
    	    entity.setBidWinMnyStr(entity.getBidWinMny().toString());
        }
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                //自制 签订数量
                entity.setSelfFlag(1);
                entity.setContractSign(0);
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        service.insertOrUpdate(entity);
    	MaterialPicketageVO vo = BeanMapper.map(entity, MaterialPicketageVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }


    @ApiOperation("查询详情")
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialPicketageVO> queryDetail(@RequestParam Long id) {
    	MaterialPicketageEntity entity = service.selectById(id);
//        materialPicketage.afterApprovalProcessor(id,0,"BT202302000003");
        if(!ListUtil.isEmpty(entity.getMaterialPicketagePurchaseDetailList()) || !ListUtil.isEmpty(entity.getMaterialPicketageRentDetailList())){
            List<Long> detailIds = new ArrayList<>();
            List<Long> purchaseIds = entity.getMaterialPicketagePurchaseDetailList().stream().map(MaterialPicketagePurchaseDetailEntity::getId).collect(Collectors.toList());
            List<Long> rentIds = entity.getMaterialPicketageRentDetailList().stream().map(MaterialPicketageRentDetailEntity::getId).collect(Collectors.toList());
            detailIds.addAll(purchaseIds);
            detailIds.addAll(rentIds);
            Map<Long, List<MaterialPicketageSupplierEntity>> supplierMap=new HashMap<>();
            if (CollectionUtils.isNotEmpty(detailIds)){
                QueryParam param = new QueryParam();
                param.getParams().put("picketageDetailId",new Parameter(QueryParam.IN,detailIds));
                List<MaterialPicketageSupplierEntity> supplierEntities = materialPicketageSupplierService.queryList(param, false);
                if (CollectionUtils.isNotEmpty(supplierEntities)){
                    supplierMap = supplierEntities.stream().collect(Collectors.groupingBy(MaterialPicketageSupplierEntity::getPicketageDetailId));
                }
                if (!supplierMap.isEmpty()){
                    for (MaterialPicketageRentDetailEntity rent : entity.getMaterialPicketageRentDetailList()) {
                        rent.setMaterialPicketageSupplierList(supplierMap.get(rent.getId()));
                    }
                    for (MaterialPicketagePurchaseDetailEntity purchase : entity.getMaterialPicketagePurchaseDetailList()) {
                        purchase.setMaterialPicketageSupplierList(supplierMap.get(purchase.getId()));
                    }
                }
            }
        }
    	MaterialPicketageVO vo = BeanMapper.map(entity, MaterialPicketageVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    /**
     *  根据询价单 id 查询 询价清单 和报价记录
     * @param inquiryId
     * @return 询价清单--{purchaseList、rentList} 报价记录--{quoteList} 清单数量统计--{totalMap}
     */
    @RequestMapping(value = "/queryByInquiryToDetailAndQuote", method = RequestMethod.GET)
    @ResponseBody
    CommonResponse<JSONObject> queryByInquiryToDetailAndQuote(@RequestParam(value = "inquiryId") String inquiryId){
        return service.queryByInquiryToDetailAndQuote(inquiryId);
    }

    @ApiOperation("批量删除单据")
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialPicketageVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MaterialPicketageVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MaterialPicketageVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }


    @ApiOperation("查询列表")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialPicketageVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("name");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("bidWinnerName");
        /** 租户隔离 */
        Map<String, Parameter> params = param.getParams();
        if (params.containsKey("contractSign")){
            Integer contractSign= Integer.parseInt(params.get("contractSign").getValue().toString());
            params.remove("contractSign");
            if (contractSign==1){
                param.getParams().put("contractSign", new Parameter(QueryParam.GT,0));
            }else {
                param.getParams().put("contractSign", new Parameter(QueryParam.EQ,0));
            }
        }
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        UserContext userContext = sessionManager.getUserContext();
        String authOrgIds = userContext.getAuthOrgIds();
        if (StringUtils.isNotEmpty(authOrgIds)) {
            CommonResponse<List<OrgVO>> authResponse =
                    iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).
                            collect(Collectors.toList()));
            param.getParams().put("orgId", new Parameter(QueryParam.IN, authResponse.getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        } else {
            param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        IPage<MaterialPicketageEntity> page = service.queryPage(param,false);
        IPage<MaterialPicketageVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialPicketageVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    @ApiOperation("导出")
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("name");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("bidWinnerName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        Map<String, Parameter> params = param.getParams();
        if (params.containsKey("contractSign")){
            Integer contractSign= Integer.parseInt(params.get("contractSign").getValue().toString());
            params.remove("contractSign");
            if (contractSign==1){
                param.getParams().put("contractSign", new Parameter(QueryParam.GT,0));
            }else {
                param.getParams().put("contractSign", new Parameter(QueryParam.EQ,0));
            }
        }
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialPicketageEntity>  list= service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<MaterialPicketageVO> vos = BeanMapper.mapList(list, MaterialPicketageVO.class);
        if (CollectionUtils.isNotEmpty(vos)){
            for (MaterialPicketageVO vo : vos) {
                vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
                vo.setPurchaseTypeName(vo.getPurchaseType()==1 ? "项目自采":"公司集采");
                vo.setPricingTypeName(vo.getPricingType()==1 ? "采购":"租赁");
                vo.setContractSignStr(vo.getContractSign()>0 ? vo.getContractSign()+"" : "未签订" );
            }
        }
        beans.put("records", vos);
        ExcelExport.getInstance().export("MaterialPicketage-export.xlsx", beans, response);
    }


    @ApiOperation("参照")
    @RequestMapping(value = "/refMaterialPicketageData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialPicketageVO>> refMaterialPicketageData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MaterialPicketageEntity> page = service.queryPage(param,false);
        IPage<MaterialPicketageVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialPicketageVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
